@@ -107,7 +107,7 @@ class DocumentSchema(object):
 
         doc_type = getattr(self, '_doc_type', self.__class__.__name__)
         self._doc['doc_type'] = doc_type
-
+        
         for prop in self._properties.values():
             if prop.name in properties:
                 value = properties.pop(prop.name)
@@ -116,6 +116,7 @@ class DocumentSchema(object):
             else:
                 value = prop.default_value()
             prop.__property_init__(self, value)
+            self.__dict__[prop.name] = value
 
         _dynamic_properties = properties.copy()
         for attr_name, value in _dynamic_properties.iteritems():
@@ -226,9 +227,9 @@ class DocumentSchema(object):
         """
         if self._dynamic_properties and key in self._dynamic_properties:
             return self._dynamic_properties[key]
-        elif key  in ('_id', '_rev', '_attachments'):
+        elif key  in ('_id', '_rev', '_attachments', 'doc_type'):
             return self._doc.get(key)
-        return getattr(super(DocumentSchema, self), key)
+        return self.__dict__[key]
 
     def __getitem__(self, key):
         """ get property value
@@ -344,7 +345,7 @@ class DocumentSchema(object):
                 pass
 
         kwargs.update(self._dynamic_properties)
-        obj = type(self)(**kwargs)
+        obj = self.__class__(**kwargs)
         obj._doc = self._doc
 
         return obj
@@ -396,12 +397,15 @@ class DocumentBase(DocumentSchema):
     _db = None
 
     def __init__(self, _d=None, **kwargs):
-        docid = None
-        if '_id' in kwargs:
-            docid = kwargs.pop('_id')
+        _d = _d or {}
+        
+        docid = kwargs.pop('_id', _d.pop("_id", ""))
+        docrev = kwargs.pop('_rev', _d.pop("_rev", ""))
+        
         DocumentSchema.__init__(self, _d, **kwargs)
-        if docid is not None:
-            self._doc['_id'] = valid_id(docid)
+        
+        if docid: self._doc['_id'] = valid_id(docid)
+        if docrev: self._doc['_rev'] = docrev            
 
     @classmethod
     def set_db(cls, db):
@@ -422,11 +426,10 @@ class DocumentBase(DocumentSchema):
         @params db: couchdbkit.core.Database instance
         """
         self.validate()
-        if self._db is None:
-            raise TypeError("doc database required to save document")
+        db = self.get_db()
 
         doc = self.to_json()
-        self._db.save_doc(doc, **params)
+        db.save_doc(doc, **params)
         if '_id' in doc and '_rev' in doc:
             self._doc.update(doc)
         elif '_id' in doc:
@@ -435,7 +438,7 @@ class DocumentBase(DocumentSchema):
     store = save
 
     @classmethod
-    def bulk_save(cls, docs, use_uuids=True, all_or_nothing=False):
+    def save_docs(cls, docs, use_uuids=True, all_or_nothing=False):
         """ Save multiple documents in database.
 
         @params docs: list of couchdbkit.schema.Document instance
@@ -452,24 +455,24 @@ class DocumentBase(DocumentSchema):
         if not len(docs_to_save) == len(docs):
             raise ValueError("one of your documents does not have the correct type")
         cls._db.bulk_save(docs_to_save, use_uuids=use_uuids, all_or_nothing=all_or_nothing)
+    
+    bulk_save = save_docs
 
     @classmethod
     def get(cls, docid, rev=None, db=None, dynamic_properties=True):
         """ get document with `docid`
         """
-        if db is not None:
-            cls._db = db
+        if not db:
+            db = cls.get_db()
         cls._allow_dynamic_properties = dynamic_properties
-        if cls._db is None:
-            raise TypeError("doc database required to save document")
-        return cls._db.get(docid, rev=rev, wrapper=cls.wrap)
+        return db.get(docid, rev=rev, wrapper=cls.wrap)
 
     @classmethod
     def get_or_create(cls, docid=None, db=None, dynamic_properties=True, **params):
         """ get  or create document with `docid` """
-        if db is not None:
+       
+        if db:
             cls._db = db
-
         cls._allow_dynamic_properties = dynamic_properties
 
         if cls._db is None:
@@ -496,13 +499,10 @@ class DocumentBase(DocumentSchema):
         """ Delete document from the database.
         @params db: couchdbkit.core.Database instance
         """
-        if self._db is None:
-            raise TypeError("doc database required to save document")
-
         if self.new_document:
             raise TypeError("the document is not saved")
-
-        self._db.delete_doc(self._id)
+        
+        db = self.get_db()
 
         # reinit document
         del self._doc['_id']
@@ -526,21 +526,25 @@ class AttachmentMixin(object):
 
         @return: bool, True if everything was ok.
         """
-        if not hasattr(self, '_db'):
-            raise TypeError("doc database required to save document")
-        return self.__class__._db.put_attachment(self._doc, content, name=name,
+        db = self.get_db() 
+        return db.put_attachment(self._doc, content, name=name,
             content_type=content_type, content_length=content_length)
 
     def delete_attachment(self, name):
         """ delete document attachment
 
-        @param name: name of attachement
+        @param name: name of attachment
 
-        @return: dict, withm member ok setto True if delete was ok.
+        @return: dict, with member ok set to True if delete was ok.
         """
-        if not hasattr(self, '_db'):
-            raise TypeError("doc database required to save document")
-        return self.__class__._db.delete_attachment(self._doc, name)
+
+        db = self.get_db()
+        result = db.delete_attachment(self._doc, name)
+        try:
+            self._doc['_attachments'].pop(name)
+        except KeyError:
+            pass
+        return result
 
     def fetch_attachment(self, name, stream=False):
         """ get attachment in a adocument
@@ -551,10 +555,8 @@ class AttachmentMixin(object):
 
         @return: str or unicode, attachment
         """
-        if not hasattr(self, '_db'):
-            raise TypeError("doc database required to save document")
-        return self.__class__._db.fetch_attachment(self._doc, name,
-                                            stream=stream)
+        db = self.get_db()
+        return db.fetch_attachment(self._doc, name, stream=stream)
 
 
 class QueryMixin(object):
