@@ -19,7 +19,6 @@ class ClientServerTestCase(unittest.TestCase):
         self.consumer = Consumer(self.db)
         
     def tearDown(self):
-        self.consumer.close()
         try:
             del self.server['couchdbkit_test']
         except:
@@ -44,8 +43,8 @@ class ClientServerTestCase(unittest.TestCase):
             self.assert_(line["last_seq"] == 1)
             self.assert_(len(line["results"]) == 1)
             
-        self.consumer.register_callback(test_line)
-        t =  threading.Thread(target=self.consumer.wait_once)
+        t =  threading.Thread(target=self.consumer.wait_once,
+                kwargs=dict(cb=test_line))
         t.daemon = True
         t.start()
         doc = {}
@@ -56,8 +55,8 @@ class ClientServerTestCase(unittest.TestCase):
         def test_line(line):
             self.lines.append(line)
             
-        self.consumer.register_callback(test_line)
-        t =  threading.Thread(target=self.consumer.wait)
+        t =  threading.Thread(target=self.consumer.wait,
+                kwargs=dict(cb=test_line))
         t.daemon = True
         t.start()
         
@@ -75,4 +74,4 @@ class ClientServerTestCase(unittest.TestCase):
         self.assert_(self.lines[5]["id"] == "test5")
         
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
